@@ -132,41 +132,19 @@ external_server_step(void *conn_context __attribute__((unused)),
     return SASL_CONTINUE;
   }
 
-  if (clientinlen		/* if we have a non-zero authorization id */
-      && strcmp(clientin,	/* and it's not the same as the auth_id */
-		sparams->utils->conn->external.auth_id)) {
-    /* The user's trying to authorize as someone they didn't
-     * authenticate as; we need to ask the application if this is
-     * kosher. */
-    int (*authorize_cb)(void *context,
-			const char *auth_identity,
-			const char *requested_user,
-			char **user,
-			const char **errstr);
-    void *authorize_context;
-
-    if ((sparams->utils->getcallback(sparams->utils->conn,
-				     SASL_CB_PROXY_POLICY,
-				     (int (**)()) &authorize_cb,
-				     &authorize_context)
-	 != SASL_OK)
-	|| ! authorize_cb)
-      return SASL_NOAUTHZ;
-
-    if (authorize_cb(authorize_context,
-		     sparams->utils->conn->external.auth_id,
-		     clientin,
-		     &oparams->user,
-		     errstr)
-	!= SASL_OK) {
-      return SASL_NOAUTHZ;
-    }
+  if (clientinlen) {		/* if we have a non-zero authorization id */
+      /* The user's trying to authorize as someone they didn't
+       * authenticate as */
+      result = _sasl_strdup(clientin, &oparams->user, NULL);
+      if (result != SASL_OK)
+	  return result;
   } else {
-    result = _sasl_strdup(sparams->utils->conn->external.auth_id,
-			  &oparams->user,
-			  NULL);
-    if (result != SASL_OK)
-      return result;
+      /* just copy the authid to the userid */
+      result = _sasl_strdup(sparams->utils->conn->external.auth_id,
+			    &oparams->user,
+			    NULL);
+      if (result != SASL_OK)
+	  return result;
   }
   
   result = _sasl_strdup(sparams->utils->conn->external.auth_id,
@@ -511,7 +489,7 @@ server_idle(sasl_conn_t *conn)
 static int load_config(const sasl_callback_t *verifyfile_cb)
 {
   int result;
-  char *path_to_config=NULL;
+  char *path_to_config=NULL, *c;
   char *config_filename=NULL;
   int len;
   const sasl_callback_t *getpath_cb=NULL;
@@ -527,6 +505,10 @@ static int load_config(const sasl_callback_t *verifyfile_cb)
   if (result!=SASL_OK) return result;
   if (path_to_config == NULL) path_to_config = "";
 
+  if ((c = strchr(path_to_config, ':'))) {
+      *c = '\0';
+  }
+
   /* length = length of path + '/' + length of appname + ".conf" + 1
      for '\0' */
   len = strlen(path_to_config)+2+ strlen(global_callbacks.appname)+5+1;
@@ -545,7 +527,8 @@ static int load_config(const sasl_callback_t *verifyfile_cb)
 
   /* Ask the application if it's safe to use this file */
   result = ((sasl_verifyfile_t *)(verifyfile_cb->proc))(verifyfile_cb->context,
-							config_filename);	  
+							config_filename);
+
   /* returns continue if this file is to be skipped */
   
   /* returns SASL_CONTINUE if doesn't exist
@@ -555,6 +538,7 @@ static int load_config(const sasl_callback_t *verifyfile_cb)
     result=sasl_config_init(config_filename);
 
   sasl_FREE(config_filename);
+  sasl_FREE(path_to_config);
 
   return result;
 }
@@ -855,25 +839,48 @@ int sasl_server_step(sasl_conn_t *conn,
 		     unsigned *serveroutlen,
 		     const char **errstr)
 {
-  /* cast */
-  sasl_server_conn_t *s_conn;
-  s_conn= (sasl_server_conn_t *) conn;
+    int ret;
+    sasl_server_conn_t *s_conn = (sasl_server_conn_t *) conn;  /* cast */
 
-  /* check parameters */
-  if ((clientin==NULL) && (clientinlen>0))
-    return SASL_BADPARAM;
+    /* check parameters */
+    if ((clientin==NULL) && (clientinlen>0))
+	return SASL_BADPARAM;
 
-  if (errstr)
-    *errstr = NULL;
+    if (errstr)
+	*errstr = NULL;
 
-  return s_conn->mech->plug->mech_step(conn->context,
-				       s_conn->sparams,
-				       clientin,
-				       clientinlen,
-				       serverout,
-				       (int *) serveroutlen,
-				       &conn->oparams,
-				       errstr);
+    ret = s_conn->mech->plug->mech_step(conn->context,
+					s_conn->sparams,
+					clientin,
+					clientinlen,
+					serverout,
+					(int *) serveroutlen,
+					&conn->oparams,
+					errstr);
+
+    if (ret == SASL_OK) {
+	sasl_authorize_t *authproc;
+	void *auth_context;
+	const char *canonuser;
+
+	/* now let's see if authname is allowed to proxy for username! */
+
+	/* check the proxy callback */
+	if (_sasl_getcallback(&s_conn->base, SASL_CB_PROXY_POLICY,
+			      &authproc, &auth_context)
+	    != SASL_OK) {
+	    return SASL_NOAUTHZ;
+	}
+	ret = authproc(auth_context, s_conn->base.oparams.authid,
+		       s_conn->base.oparams.user, &canonuser, errstr);
+
+	if (ret == SASL_OK && canonuser != NULL) {
+	    sasl_FREE(s_conn->base.oparams.user);
+	    s_conn->base.oparams.user = (char *) canonuser;
+	}
+    }
+
+    return ret;
 }
 
 /* returns the length of all the mechanisms
@@ -1001,7 +1008,7 @@ static int _sasl_checkpass(const char *mech, const char *service,
 
 #ifdef HAVE_PAM
     if (!strcmp(mech, "PAM")) {
-	result = _sasl_PAM_verify_password(user, pass, NULL);
+	result = _sasl_PAM_verify_password(user, pass, service, NULL);
     }
 #endif
 
